@@ -4,9 +4,9 @@ jdate_update <- function(x, fields, ...) {
     x <- vec_recycle(x, size)
     fields <- vec_cast_common(!!!fields, .to = integer())
     fields <- vec_recycle_common(!!!fields, .size = size)
-    fields <- df_list_propagate_missing(fields)
     fields_x <- jdate_get_fields_cpp(x)
     fields_out <- vec_assign(fields_x, names(fields), fields)
+    fields_out <- df_list_propagate_missing(fields_out)
     out <- jdate_make_cpp(fields_out)
     names(out) <- names(x)
     jdate(out)
@@ -29,9 +29,9 @@ jdatetime_update <- function(x, fields, ..., ambiguous = NULL) {
 
     fields <- vec_cast_common(!!!fields, .to = integer())
     fields <- vec_recycle_common(!!!fields, .size = size)
-    fields <- df_list_propagate_missing(fields)
     fields_x <- jdatetime_get_fields_cpp(x)
     fields_out <- vec_assign(fields_x, names(fields), fields)
+    fields_out <- df_list_propagate_missing(fields_out)
 
     if (is.null(ambiguous)) {
         out <- jdatetime_make_with_reference_cpp(fields_out, tz, x)
