@@ -1,10 +1,5 @@
 #include "shide.h"
-#include "jalali.h"
-
-enum class choose;
-choose string_to_choose(const std::string& choose_str);
-double jdatetime_from_local_seconds(const date::local_seconds& ls, const date::time_zone* tz,
-                                    date::local_info& info, const choose& c);
+#include <shide/make.h>
 
 [[cpp11::register]]
 cpp11::writable::doubles
@@ -23,8 +18,7 @@ jdate_parse_cpp(const cpp11::strings& x, const cpp11::strings& format)
     std::istringstream is;
     std::chrono::minutes* offptr{};
     std::string* abbrev{};
-    sh_year_month_day ymd{};
-    date::days days_since_epoch;
+    std::optional<double> d{};
 
     for (R_xlen_t i = 0; i < size; ++i)
     {
@@ -50,16 +44,9 @@ jdate_parse_cpp(const cpp11::strings& x, const cpp11::strings& format)
             continue;
         }
 
-        ymd = {fds.ymd.year(), fds.ymd.month(), fds.ymd.day()};
-
-        if (!ymd.ok())
-        {
-            out[i] = NA_REAL;
-            continue;
-        }
-
-        days_since_epoch = local_days(ymd).time_since_epoch();
-        out[i] = static_cast<double>(days_since_epoch.count());
+        auto ymd = sh_year_month_day{fds.ymd.year(), fds.ymd.month(), fds.ymd.day()};
+        d = make_jdate(ymd);
+        out[i] = d.has_value() ? *d : NA_REAL;
     }
 
     return out;
@@ -74,8 +61,13 @@ jdatetime_parse_cpp(const cpp11::strings& x, const cpp11::strings& format,
         cpp11::stop("`format` must have size 1.");
     }
 
-    const auto Ambiguous{ string_to_choose(ambiguous) };
-    date::local_seconds ls;
+    const auto opt{ string_to_choose(ambiguous) };
+
+    if (!opt) {
+        cpp11::stop("Invalid ambiguous relolution strategy");
+    }
+
+    const auto Ambiguous{*opt};
     const date::time_zone* tz{};
     date::local_info info;
     const std::string tz_name(tzone[0]);
@@ -95,6 +87,9 @@ jdatetime_parse_cpp(const cpp11::strings& x, const cpp11::strings& format,
     std::chrono::minutes* offptr{};
     std::string* abbrev{};
     sh_year_month_day ymd{};
+    sh_fields sh_fds{};
+    sh_fds.has_tod = true;
+    std::optional<double> dt{};
 
     for (R_xlen_t i = 0; i < size; ++i)
     {
@@ -135,8 +130,10 @@ jdatetime_parse_cpp(const cpp11::strings& x, const cpp11::strings& format,
             continue;
         }
 
-        ls = local_days(ymd) + fds.tod.to_duration();
-        out[i] = jdatetime_from_local_seconds(ls, tz, info, Ambiguous);
+        sh_fds.ymd = ymd;
+        sh_fds.tod = hour_minute_second(fds.tod.to_duration());
+        dt = make_jdatetime(sh_fds, tz, info, Ambiguous);
+        out[i] = dt.has_value() ? *dt : NA_REAL;
     }
 
     return out;
